@@ -1,11 +1,176 @@
 package Cwd;
+
+=head1 NAME
+
+Cwd - get pathname of current working directory
+
+=head1 SYNOPSIS
+
+    use Cwd;
+    my $dir = getcwd;
+
+    use Cwd 'abs_path';
+    my $abs_path = abs_path($file);
+
+=head1 DESCRIPTION
+
+This module provides functions for determining the pathname of the
+current working directory.  It is recommended that getcwd (or another
+*cwd() function) be used in I<all> code to ensure portability.
+
+By default, it exports the functions cwd(), getcwd(), fastcwd(), and
+fastgetcwd() (and, on Win32, getdcwd()) into the caller's namespace.  
+
+
+=head2 getcwd and friends
+
+Each of these functions are called without arguments and return the
+absolute path of the current working directory.
+
+=over 4
+
+=item getcwd
+
+    my $cwd = getcwd();
+
+Returns the current working directory.
+
+Re-implements the getcwd(3) (or getwd(3)) functions in Perl.
+
+=item cwd
+
+    my $cwd = cwd();
+
+The cwd() is the most natural form for the current architecture. For
+most systems it is identical to `pwd` (but without the trailing line
+terminator).
+
+=item fastcwd
+
+    my $cwd = fastcwd();
+
+A more dangerous version of getcwd(), but potentially faster.
+
+It might conceivably chdir() you out of a directory that it can't
+chdir() you back into.  If fastcwd encounters a problem it will return
+undef but will probably leave you in a different directory.  For a
+measure of extra security, if everything appears to have worked, the
+fastcwd() function will check that it leaves you in the same directory
+that it started in. If it has changed it will C<die> with the message
+"Unstable directory path, current directory changed
+unexpectedly". That should never happen.
+
+=item fastgetcwd
+
+  my $cwd = fastgetcwd();
+
+The fastgetcwd() function is provided as a synonym for cwd().
+
+=item getdcwd
+
+    my $cwd = getdcwd();
+    my $cwd = getdcwd('C:');
+
+The getdcwd() function is also provided on Win32 to get the current working
+directory on the specified drive, since Windows maintains a separate current
+working directory for each drive.  If no drive is specified then the current
+drive is assumed.
+
+This function simply calls the Microsoft C library _getdcwd() function.
+
+=back
+
+
+=head2 abs_path and friends
+
+These functions are exported only on request.  They each take a single
+argument and return the absolute pathname for it.  If no argument is
+given they'll use the current working directory.
+
+=over 4
+
+=item abs_path
+
+  my $abs_path = abs_path($file);
+
+Uses the same algorithm as getcwd().  Symbolic links and relative-path
+components ("." and "..") are resolved to return the canonical
+pathname, just like realpath(3).
+
+=item realpath
+
+  my $abs_path = realpath($file);
+
+A synonym for abs_path().
+
+=item fast_abs_path
+
+  my $abs_path = fast_abs_path($file);
+
+A more dangerous, but potentially faster version of abs_path.
+
+=back
+
+=head2 $ENV{PWD}
+
+If you ask to override your chdir() built-in function, 
+
+  use Cwd qw(chdir);
+
+then your PWD environment variable will be kept up to date.  Note that
+it will only be kept up to date if all packages which use chdir import
+it from Cwd.
+
+
+=head1 NOTES
+
+=over 4
+
+=item *
+
+Since the path seperators are different on some operating systems ('/'
+on Unix, ':' on MacPerl, etc...) we recommend you use the File::Spec
+modules wherever portability is a concern.
+
+=item *
+
+Actually, on Mac OS, the C<getcwd()>, C<fastgetcwd()> and C<fastcwd()>
+functions  are all aliases for the C<cwd()> function, which, on Mac OS,
+calls `pwd`. Likewise, the C<abs_path()> function is an alias for
+C<fast_abs_path()>.
+
+=back
+
+=head1 AUTHOR
+
+Originally by the perl5-porters.
+
+Maintained by Ken Williams <KWILLIAMS@cpan.org>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2004 by the Perl 5 Porters.  All rights reserved.
+
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+Portions of the C code in this library are copyright (c) 1994 by the
+Regents of the University of California.  All rights reserved.  The
+license on this code is compatible with the licensing of the rest of
+the distribution - please see the source code in F<Cwd.xs> for the
+details.
+
+=head1 SEE ALSO
+
+L<File::chdir>
+
+=cut
+
 use strict;
 use Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
 
-$VERSION = '3.58_01';
-my $xs_version = $VERSION;
-$VERSION =~ tr/_//d;
+$VERSION = '3.02';
 
 @ISA = qw/ Exporter /;
 @EXPORT = qw(cwd getcwd fastcwd fastgetcwd);
@@ -34,60 +199,18 @@ if ($^O eq 'os2') {
     return 1;
 }
 
-# Need to look up the feature settings on VMS.  The preferred way is to use the
-# VMS::Feature module, but that may not be available to dual life modules.
 
-my $use_vms_feature;
-BEGIN {
-    if ($^O eq 'VMS') {
-        if (eval { local $SIG{__DIE__}; require VMS::Feature; }) {
-            $use_vms_feature = 1;
-        }
-    }
+if ( $] >= 5.006 ) {
+  require XSLoader;
+  XSLoader::load( __PACKAGE__, $VERSION );
+} else {
+  require DynaLoader;
+  push @ISA, 'DynaLoader';
+  __PACKAGE__->bootstrap( $VERSION );
 }
 
-# Need to look up the UNIX report mode.  This may become a dynamic mode
-# in the future.
-sub _vms_unix_rpt {
-    my $unix_rpt;
-    if ($use_vms_feature) {
-        $unix_rpt = VMS::Feature::current("filename_unix_report");
-    } else {
-        my $env_unix_rpt = $ENV{'DECC$FILENAME_UNIX_REPORT'} || '';
-        $unix_rpt = $env_unix_rpt =~ /^[ET1]/i; 
-    }
-    return $unix_rpt;
-}
-
-# Need to look up the EFS character set mode.  This may become a dynamic
-# mode in the future.
-sub _vms_efs {
-    my $efs;
-    if ($use_vms_feature) {
-        $efs = VMS::Feature::current("efs_charset");
-    } else {
-        my $env_efs = $ENV{'DECC$EFS_CHARSET'} || '';
-        $efs = $env_efs =~ /^[ET1]/i; 
-    }
-    return $efs;
-}
-
-
-# If loading the XS stuff doesn't work, we can fall back to pure perl
-if(! defined &getcwd && defined &DynaLoader::boot_DynaLoader) {
-  eval {#eval is questionable since we are handling potential errors like
-        #"Cwd object version 3.48 does not match bootstrap parameter 3.50
-        #at lib/DynaLoader.pm line 216." by having this eval
-    if ( $] >= 5.006 ) {
-      require XSLoader;
-      XSLoader::load( __PACKAGE__, $xs_version);
-    } else {
-      require DynaLoader;
-      push @ISA, 'DynaLoader';
-      __PACKAGE__->bootstrap( $xs_version );
-    }
-  };
-}
+# Must be after the DynaLoader stuff:
+$VERSION = eval $VERSION;
 
 # Big nasty table of function aliases
 my %METHOD_MAP =
@@ -122,7 +245,6 @@ my %METHOD_MAP =
     abs_path		=> 'fast_abs_path',
    },
 
-   # QNX4.  QNX6 has a $os of 'nto'.
    qnx =>
    {
     cwd			=> '_qnx_cwd',
@@ -158,55 +280,28 @@ my %METHOD_MAP =
     fastcwd		=> 'cwd',
     abs_path		=> 'fast_abs_path',
    },
-
-   amigaos =>
-   {
-    getcwd              => '_backtick_pwd',
-    fastgetcwd          => '_backtick_pwd',
-    fastcwd             => '_backtick_pwd',
-    abs_path            => 'fast_abs_path',
-   }
   );
 
 $METHOD_MAP{NT} = $METHOD_MAP{MSWin32};
+$METHOD_MAP{nto} = $METHOD_MAP{qnx};
 
 
 # Find the pwd command in the expected locations.  We assume these
 # are safe.  This prevents _backtick_pwd() consulting $ENV{PATH}
 # so everything works under taint mode.
 my $pwd_cmd;
-if($^O ne 'MSWin32') {
-    foreach my $try ('/bin/pwd',
-		     '/usr/bin/pwd',
-		     '/QOpenSys/bin/pwd', # OS/400 PASE.
-		    ) {
-	if( -x $try ) {
-	    $pwd_cmd = $try;
-	    last;
-	}
+foreach my $try ('/bin/pwd',
+		 '/usr/bin/pwd',
+		 '/QOpenSys/bin/pwd', # OS/400 PASE.
+		) {
+
+    if( -x $try ) {
+        $pwd_cmd = $try;
+        last;
     }
 }
-
-# Android has a built-in pwd. Using $pwd_cmd will DTRT if
-# this perl was compiled with -Dd_useshellcmds, which is the
-# default for Android, but the block below is needed for the
-# miniperl running on the host when cross-compiling, and
-# potentially for native builds with -Ud_useshellcmds.
-if ($^O =~ /android/) {
-    # If targetsh is executable, then we're either a full
-    # perl, or a miniperl for a native build.
-    if (-x $Config::Config{targetsh}) {
-        $pwd_cmd = "$Config::Config{targetsh} -c pwd"
-    }
-    else {
-        my $sh = $Config::Config{sh} || (-x '/system/bin/sh' ? '/system/bin/sh' : 'sh');
-        $pwd_cmd = "$sh -c pwd"
-    }
-}
-
-my $found_pwd_cmd = defined($pwd_cmd);
 unless ($pwd_cmd) {
-    # Isn't this wrong?  _backtick_pwd() will fail if someone has
+    # Isn't this wrong?  _backtick_pwd() will fail if somenone has
     # pwd in their path but it is not /bin/pwd or /usr/bin/pwd?
     # See [perl #16774]. --jhi
     $pwd_cmd = 'pwd';
@@ -218,13 +313,7 @@ sub _croak { require Carp; Carp::croak(@_) }
 
 # The 'natural and safe form' for UNIX (pwd may be setuid root)
 sub _backtick_pwd {
-
-    # Localize %ENV entries in a way that won't create new hash keys.
-    # Under AmigaOS we don't want to localize as it stops perl from
-    # finding 'sh' in the PATH.
-    my @localize = grep exists $ENV{$_}, qw(PATH IFS CDPATH ENV BASH_ENV) if $^O ne "amigaos";
-    local @ENV{@localize} if @localize;
-    
+    local @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};
     my $cwd = `$pwd_cmd`;
     # Belt-and-suspenders in case someone said "undef $/".
     local $/ = "\n";
@@ -239,20 +328,9 @@ sub _backtick_pwd {
 unless ($METHOD_MAP{$^O}{cwd} or defined &cwd) {
     # The pwd command is not available in some chroot(2)'ed environments
     my $sep = $Config::Config{path_sep} || ':';
-    my $os = $^O;  # Protect $^O from tainting
-
-
-    # Try again to find a pwd, this time searching the whole PATH.
-    if (defined $ENV{PATH} and $os ne 'MSWin32') {  # no pwd on Windows
-	my @candidates = split($sep, $ENV{PATH});
-	while (!$found_pwd_cmd and @candidates) {
-	    my $candidate = shift @candidates;
-	    $found_pwd_cmd = 1 if -x "$candidate/pwd";
-	}
-    }
-
-    # MacOS has some special magic to make `pwd` work.
-    if( $os eq 'MacOS' || $found_pwd_cmd )
+    if( $^O eq 'MacOS' || (defined $ENV{PATH} &&
+			   $^O ne 'MSWin32' &&  # no pwd on Windows
+			   grep { -x "$_/pwd" } split($sep, $ENV{PATH})) )
     {
 	*cwd = \&_backtick_pwd;
     }
@@ -261,26 +339,20 @@ unless ($METHOD_MAP{$^O}{cwd} or defined &cwd) {
     }
 }
 
-if ($^O eq 'cygwin') {
-  # We need to make sure cwd() is called with no args, because it's
-  # got an arg-less prototype and will die if args are present.
-  local $^W = 0;
-  my $orig_cwd = \&cwd;
-  *cwd = sub { &$orig_cwd() }
-}
-
-
 # set a reasonable (and very safe) default for fastgetcwd, in case it
 # isn't redefined later (20001212 rspier)
 *fastgetcwd = \&cwd;
 
-# A non-XS version of getcwd() - also used to bootstrap the perl build
-# process, when miniperl is running and no XS loading happens.
-sub _perl_getcwd
+# By Brandon S. Allbery
+#
+# Usage: $cwd = getcwd();
+
+sub getcwd
 {
     abs_path('.');
 }
 
+
 # By John Bazik
 #
 # Usage: $cwd = &fastcwd;
@@ -362,13 +434,7 @@ sub chdir_init {
 
 sub chdir {
     my $newdir = @_ ? shift : '';	# allow for no arg (chdir to HOME dir)
-    if ($^O eq "cygwin") {
-      $newdir =~ s|\A///+|//|;
-      $newdir =~ s|(?<=[^/])//+|/|g;
-    }
-    elsif ($^O ne 'MSWin32') {
-      $newdir =~ s|///*|/|g;
-    }
+    $newdir =~ s|///*|/|g unless $^O eq 'MSWin32';
     chdir_init() unless $chdir_init;
     my $newpwd;
     if ($^O eq 'MSWin32') {
@@ -389,9 +455,7 @@ sub chdir {
 	return 1;
     }
 
-    if (ref $newdir eq 'GLOB') { # in case a file/dir handle is passed in
-	$ENV{'PWD'} = cwd();
-    } elsif ($newdir =~ m#^/#s) {
+    if ($newdir =~ m#^/#s) {
 	$ENV{'PWD'} = $newdir;
     } else {
 	my @curdir = split(m#/#,$ENV{'PWD'});
@@ -450,9 +514,8 @@ sub _perl_abs_path
 	local *PARENT;
 	unless (opendir(PARENT, $dotdots))
 	{
-	    # probably a permissions issue.  Try the native command.
-	    require File::Spec;
-	    return File::Spec->rel2abs( $start, _backtick_pwd() );
+	    _carp("opendir($dotdots): $!");
+	    return '';
 	}
 	unless (@cst = stat($dotdots))
 	{
@@ -496,8 +559,8 @@ sub fast_abs_path {
 
     # Detaint else we'll explode in taint mode.  This is safe because
     # we're not doing anything dangerous with it.
-    ($path) = $path =~ /(.*)/s;
-    ($cwd)  = $cwd  =~ /(.*)/s;
+    ($path) = $path =~ /(.*)/;
+    ($cwd)  = $cwd  =~ /(.*)/;
 
     unless (-e $path) {
  	_croak("$path: No such file or directory");
@@ -555,119 +618,50 @@ sub _vms_cwd {
 
 sub _vms_abs_path {
     return $ENV{'DEFAULT'} unless @_;
-    my $path = shift;
-
-    my $efs = _vms_efs;
-    my $unix_rpt = _vms_unix_rpt;
-
-    if (defined &VMS::Filespec::vmsrealpath) {
-        my $path_unix = 0;
-        my $path_vms = 0;
-
-        $path_unix = 1 if ($path =~ m#(?<=\^)/#);
-        $path_unix = 1 if ($path =~ /^\.\.?$/);
-        $path_vms = 1 if ($path =~ m#[\[<\]]#);
-        $path_vms = 1 if ($path =~ /^--?$/);
-
-        my $unix_mode = $path_unix;
-        if ($efs) {
-            # In case of a tie, the Unix report mode decides.
-            if ($path_vms == $path_unix) {
-                $unix_mode = $unix_rpt;
-            } else {
-                $unix_mode = 0 if $path_vms;
-            }
-        }
-
-        if ($unix_mode) {
-            # Unix format
-            return VMS::Filespec::unixrealpath($path);
-        }
-
-	# VMS format
-
-	my $new_path = VMS::Filespec::vmsrealpath($path);
-
-	# Perl expects directories to be in directory format
-	$new_path = VMS::Filespec::pathify($new_path) if -d $path;
-	return $new_path;
-    }
-
-    # Fallback to older algorithm if correct ones are not
-    # available.
-
-    if (-l $path) {
-        my $link_target = readlink($path);
-        die "Can't resolve link $path: $!" unless defined $link_target;
-
-        return _vms_abs_path($link_target);
-    }
 
     # may need to turn foo.dir into [.foo]
-    my $pathified = VMS::Filespec::pathify($path);
-    $path = $pathified if defined $pathified;
-	
+    my $path = VMS::Filespec::pathify($_[0]);
+    $path = $_[0] unless defined $path;
+
     return VMS::Filespec::rmsexpand($path);
 }
 
 sub _os2_cwd {
-    my $pwd = `cmd /c cd`;
-    chomp $pwd;
-    $pwd =~ s:\\:/:g ;
-    $ENV{'PWD'} = $pwd;
-    return $pwd;
-}
-
-sub _win32_cwd_simple {
-    my $pwd = `cd`;
-    chomp $pwd;
-    $pwd =~ s:\\:/:g ;
-    $ENV{'PWD'} = $pwd;
-    return $pwd;
+    $ENV{'PWD'} = `cmd /c cd`;
+    chomp $ENV{'PWD'};
+    $ENV{'PWD'} =~ s:\\:/:g ;
+    return $ENV{'PWD'};
 }
 
 sub _win32_cwd {
-    my $pwd;
-    # Need to avoid taking any sort of reference to the typeglob or the code in
-    # the optree, so that this tests the runtime state of things, as the
-    # ExtUtils::MakeMaker tests for "miniperl" need to be able to fake things at
-    # runtime by deleting the subroutine. *foo{THING} syntax on a symbol table
-    # lookup avoids needing a string eval, which has been reported to cause
-    # problems (for reasons that we haven't been able to get to the bottom of -
-    # rt.cpan.org #56225)
-    if (*{$DynaLoader::{boot_DynaLoader}}{CODE}) {
-	$pwd = Win32::GetCwd();
-    }
-    else { # miniperl
-	chomp($pwd = `cd`);
-    }
-    $pwd =~ s:\\:/:g ;
-    $ENV{'PWD'} = $pwd;
-    return $pwd;
+    $ENV{'PWD'} = Win32::GetCwd();
+    $ENV{'PWD'} =~ s:\\:/:g ;
+    return $ENV{'PWD'};
 }
 
-*_NT_cwd = defined &Win32::GetCwd ? \&_win32_cwd : \&_win32_cwd_simple;
+*_NT_cwd = \&_win32_cwd if (!defined &_NT_cwd && 
+                            defined &Win32::GetCwd);
+
+*_NT_cwd = \&_os2_cwd unless defined &_NT_cwd;
 
 sub _dos_cwd {
-    my $pwd;
     if (!defined &Dos::GetCwd) {
-        chomp($pwd = `command /c cd`);
-        $pwd =~ s:\\:/:g ;
+        $ENV{'PWD'} = `command /c cd`;
+        chomp $ENV{'PWD'};
+        $ENV{'PWD'} =~ s:\\:/:g ;
     } else {
-        $pwd = Dos::GetCwd();
+        $ENV{'PWD'} = Dos::GetCwd();
     }
-    $ENV{'PWD'} = $pwd;
-    return $pwd;
+    return $ENV{'PWD'};
 }
 
 sub _qnx_cwd {
 	local $ENV{PATH} = '';
 	local $ENV{CDPATH} = '';
 	local $ENV{ENV} = '';
-    my $pwd = `/usr/bin/fullpath -t`;
-    chomp $pwd;
-    $ENV{'PWD'} = $pwd;
-    return $pwd;
+    $ENV{'PWD'} = `/usr/bin/fullpath -t`;
+    chomp $ENV{'PWD'};
+    return $ENV{'PWD'};
 }
 
 sub _qnx_abs_path {
@@ -686,7 +680,8 @@ sub _qnx_abs_path {
 }
 
 sub _epoc_cwd {
-    return $ENV{'PWD'} = EPOC::getcwd();
+    $ENV{'PWD'} = EPOC::getcwd();
+    return $ENV{'PWD'};
 }
 
 
@@ -704,178 +699,9 @@ if (exists $METHOD_MAP{$^O}) {
 
 # In case the XS version doesn't load.
 *abs_path = \&_perl_abs_path unless defined &abs_path;
-*getcwd = \&_perl_getcwd unless defined &getcwd;
 
 # added function alias for those of us more
 # used to the libc function.  --tchrist 27-Jan-00
 *realpath = \&abs_path;
 
 1;
-__END__
-
-=head1 NAME
-
-Cwd - get pathname of current working directory
-
-=head1 SYNOPSIS
-
-    use Cwd;
-    my $dir = getcwd;
-
-    use Cwd 'abs_path';
-    my $abs_path = abs_path($file);
-
-=head1 DESCRIPTION
-
-This module provides functions for determining the pathname of the
-current working directory.  It is recommended that getcwd (or another
-*cwd() function) be used in I<all> code to ensure portability.
-
-By default, it exports the functions cwd(), getcwd(), fastcwd(), and
-fastgetcwd() (and, on Win32, getdcwd()) into the caller's namespace.  
-
-
-=head2 getcwd and friends
-
-Each of these functions are called without arguments and return the
-absolute path of the current working directory.
-
-=over 4
-
-=item getcwd
-
-    my $cwd = getcwd();
-
-Returns the current working directory.
-
-Exposes the POSIX function getcwd(3) or re-implements it if it's not
-available.
-
-=item cwd
-
-    my $cwd = cwd();
-
-The cwd() is the most natural form for the current architecture.  For
-most systems it is identical to `pwd` (but without the trailing line
-terminator).
-
-=item fastcwd
-
-    my $cwd = fastcwd();
-
-A more dangerous version of getcwd(), but potentially faster.
-
-It might conceivably chdir() you out of a directory that it can't
-chdir() you back into.  If fastcwd encounters a problem it will return
-undef but will probably leave you in a different directory.  For a
-measure of extra security, if everything appears to have worked, the
-fastcwd() function will check that it leaves you in the same directory
-that it started in.  If it has changed it will C<die> with the message
-"Unstable directory path, current directory changed
-unexpectedly".  That should never happen.
-
-=item fastgetcwd
-
-  my $cwd = fastgetcwd();
-
-The fastgetcwd() function is provided as a synonym for cwd().
-
-=item getdcwd
-
-    my $cwd = getdcwd();
-    my $cwd = getdcwd('C:');
-
-The getdcwd() function is also provided on Win32 to get the current working
-directory on the specified drive, since Windows maintains a separate current
-working directory for each drive.  If no drive is specified then the current
-drive is assumed.
-
-This function simply calls the Microsoft C library _getdcwd() function.
-
-=back
-
-
-=head2 abs_path and friends
-
-These functions are exported only on request.  They each take a single
-argument and return the absolute pathname for it.  If no argument is
-given they'll use the current working directory.
-
-=over 4
-
-=item abs_path
-
-  my $abs_path = abs_path($file);
-
-Uses the same algorithm as getcwd().  Symbolic links and relative-path
-components ("." and "..") are resolved to return the canonical
-pathname, just like realpath(3).
-
-=item realpath
-
-  my $abs_path = realpath($file);
-
-A synonym for abs_path().
-
-=item fast_abs_path
-
-  my $abs_path = fast_abs_path($file);
-
-A more dangerous, but potentially faster version of abs_path.
-
-=back
-
-=head2 $ENV{PWD}
-
-If you ask to override your chdir() built-in function, 
-
-  use Cwd qw(chdir);
-
-then your PWD environment variable will be kept up to date.  Note that
-it will only be kept up to date if all packages which use chdir import
-it from Cwd.
-
-
-=head1 NOTES
-
-=over 4
-
-=item *
-
-Since the path separators are different on some operating systems ('/'
-on Unix, ':' on MacPerl, etc...) we recommend you use the File::Spec
-modules wherever portability is a concern.
-
-=item *
-
-Actually, on Mac OS, the C<getcwd()>, C<fastgetcwd()> and C<fastcwd()>
-functions are all aliases for the C<cwd()> function, which, on Mac OS,
-calls `pwd`.  Likewise, the C<abs_path()> function is an alias for
-C<fast_abs_path()>.
-
-=back
-
-=head1 AUTHOR
-
-Originally by the perl5-porters.
-
-Maintained by Ken Williams <KWILLIAMS@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2004 by the Perl 5 Porters.  All rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-Portions of the C code in this library are copyright (c) 1994 by the
-Regents of the University of California.  All rights reserved.  The
-license on this code is compatible with the licensing of the rest of
-the distribution - please see the source code in F<Cwd.xs> for the
-details.
-
-=head1 SEE ALSO
-
-L<File::chdir>
-
-=cut
