@@ -3,8 +3,8 @@ package File::Spec;
 use strict;
 use vars qw(@ISA $VERSION);
 
-$VERSION = '3.58_01';
-$VERSION =~ tr/_//d;
+$VERSION = '3.02';
+$VERSION = eval $VERSION;
 
 my %module = (MacOS   => 'Mac',
 	      MSWin32 => 'Win32',
@@ -12,10 +12,8 @@ my %module = (MacOS   => 'Mac',
 	      VMS     => 'VMS',
 	      epoc    => 'Epoc',
 	      NetWare => 'Win32', # Yes, File::Spec::Win32 works on NetWare.
-	      symbian => 'Win32', # Yes, File::Spec::Win32 works on symbian.
-	      dos     => 'OS2',   # Yes, File::Spec::OS2 works on DJGPP.
-	      cygwin  => 'Cygwin',
-	      amigaos => 'AmigaOS');
+              dos     => 'OS2',   # Yes, File::Spec::OS2 works on DJGPP.
+	      cygwin  => 'Cygwin');
 
 
 my $module = $module{$^O} || 'Unix';
@@ -84,22 +82,13 @@ forms of these methods.
 =over 2
 
 =item canonpath
-X<canonpath>
 
 No physical check on the filesystem, but a logical cleanup of a
 path.
 
     $cpath = File::Spec->canonpath( $path ) ;
 
-Note that this does *not* collapse F<x/../y> sections into F<y>.  This
-is by design.  If F</foo> on your system is a symlink to F</bar/baz>,
-then F</foo/../quux> is actually F</bar/quux>, not F</quux> as a naive
-F<../>-removal would give you.  If you want to do this kind of
-processing, you probably want C<Cwd>'s C<realpath()> function to
-actually traverse the filesystem cleaning up paths like this.
-
 =item catdir
-X<catdir>
 
 Concatenate two or more directory names to form a complete path ending
 with a directory. But remove the trailing slash from the resulting
@@ -110,7 +99,6 @@ trailing slash :-)
     $path = File::Spec->catdir( @directories );
 
 =item catfile
-X<catfile>
 
 Concatenate one or more directory names and a filename to form a
 complete path ending with a filename
@@ -118,28 +106,24 @@ complete path ending with a filename
     $path = File::Spec->catfile( @directories, $filename );
 
 =item curdir
-X<curdir>
 
 Returns a string representation of the current directory.
 
     $curdir = File::Spec->curdir();
 
 =item devnull
-X<devnull>
 
 Returns a string representation of the null device.
 
     $devnull = File::Spec->devnull();
 
 =item rootdir
-X<rootdir>
 
 Returns a string representation of the root directory.
 
     $rootdir = File::Spec->rootdir();
 
 =item tmpdir
-X<tmpdir>
 
 Returns a string representation of the first writable directory from a
 list of possible temporary directories.  Returns the current directory
@@ -150,7 +134,6 @@ checked depends on the platform; e.g. File::Spec::Unix checks C<$ENV{TMPDIR}>
     $tmpdir = File::Spec->tmpdir();
 
 =item updir
-X<updir>
 
 Returns a string representation of the parent directory.
 
@@ -167,7 +150,6 @@ directory. (Does not strip symlinks, only '.', '..', and equivalents.)
 
 Returns a true or false value indicating, respectively, that alphabetic
 case is not or is significant when comparing file specifications.
-Cygwin and Win32 accept an optional drive argument.
 
     $is_case_tolerant = File::Spec->case_tolerant();
 
@@ -182,7 +164,6 @@ Mac OS (Classic).  It does consult the working environment for VMS
 (see L<File::Spec::VMS/file_name_is_absolute>).
 
 =item path
-X<path>
 
 Takes no argument.  Returns the environment variable C<PATH> (or the local
 platform's equivalent) as a list.
@@ -190,20 +171,16 @@ platform's equivalent) as a list.
     @PATH = File::Spec->path();
 
 =item join
-X<join, path>
 
 join is the same as catfile.
 
 =item splitpath
-X<splitpath> X<split, path>
 
 Splits a path in to volume, directory, and filename portions. On systems
 with no concept of volume, returns '' for volume. 
 
-    ($volume,$directories,$file) =
-                       File::Spec->splitpath( $path );
-    ($volume,$directories,$file) =
-                       File::Spec->splitpath( $path, $no_file );
+    ($volume,$directories,$file) = File::Spec->splitpath( $path );
+    ($volume,$directories,$file) = File::Spec->splitpath( $path, $no_file );
 
 For systems with no syntax differentiating filenames from directories, 
 assumes that the last file is a path unless C<$no_file> is true or a
@@ -216,9 +193,8 @@ The results can be passed to L</catpath()> to get back a path equivalent to
 (usually identical to) the original path.
 
 =item splitdir
-X<splitdir> X<split, dir>
 
-The opposite of L</catdir>.
+The opposite of L</catdir()>.
 
     @dirs = File::Spec->splitdir( $directories );
 
@@ -239,7 +215,6 @@ inserted if need be.  On other OSes, C<$volume> is significant.
     $full_path = File::Spec->catpath( $volume, $directory, $file );
 
 =item abs2rel
-X<abs2rel> X<absolute, path> X<relative, path>
 
 Takes a destination path and an optional base path returns a relative path
 from the base path to the destination path:
@@ -247,10 +222,10 @@ from the base path to the destination path:
     $rel_path = File::Spec->abs2rel( $path ) ;
     $rel_path = File::Spec->abs2rel( $path, $base ) ;
 
-If C<$base> is not present or '', then L<Cwd::cwd()|Cwd> is used. If C<$base> is
+If C<$base> is not present or '', then L<cwd()|Cwd> is used. If C<$base> is
 relative, then it is converted to absolute form using
 L</rel2abs()>. This means that it is taken to be relative to
-L<Cwd::cwd()|Cwd>.
+L<cwd()|Cwd>.
 
 On systems with the concept of volume, if C<$path> and C<$base> appear to be
 on two different volumes, we will not attempt to resolve the two
@@ -263,7 +238,7 @@ C<$base> filename as well. Otherwise all path components are assumed to be
 directories.
 
 If C<$path> is relative, it is converted to absolute form using L</rel2abs()>.
-This means that it is taken to be relative to L<Cwd::cwd()|Cwd>.
+This means that it is taken to be relative to L<cwd()|Cwd>.
 
 No checks against the filesystem are made.  On VMS, there is
 interaction with the working environment, as logicals and
@@ -272,16 +247,15 @@ macros are expanded.
 Based on code written by Shigio Yamaguchi.
 
 =item rel2abs()
-X<rel2abs> X<absolute, path> X<relative, path>
 
 Converts a relative path to an absolute path. 
 
     $abs_path = File::Spec->rel2abs( $path ) ;
     $abs_path = File::Spec->rel2abs( $path, $base ) ;
 
-If C<$base> is not present or '', then L<Cwd::cwd()|Cwd> is used. If C<$base> is relative,
+If C<$base> is not present or '', then L<cwd()|Cwd> is used. If C<$base> is relative,
 then it is converted to absolute form using L</rel2abs()>. This means that it
-is taken to be relative to L<Cwd::cwd()|Cwd>.
+is taken to be relative to L<cwd()|Cwd>.
 
 On systems with the concept of volume, if C<$path> and C<$base> appear to be
 on two different volumes, we will not attempt to resolve the two
@@ -293,7 +267,7 @@ On systems that have a grammar that indicates filenames, this ignores the
 C<$base> filename as well. Otherwise all path components are assumed to be
 directories.
 
-If C<$path> is absolute, it is cleaned up and returned using L</canonpath>.
+If C<$path> is absolute, it is cleaned up and returned using L</canonpath()>.
 
 No checks against the filesystem are made.  On VMS, there is
 interaction with the working environment, as logicals and
@@ -332,7 +306,7 @@ splitpath(), splitdir(), catpath() and catdir() by Barrie Slaymaker.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004-2013 by the Perl 5 Porters.  All rights reserved.
+Copyright (c) 2004 by the Perl 5 Porters.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
